# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/game/game/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/game/game/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Game\\Game\\": "packages/game/game/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Game\Game\Providers\GameServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Game'  => Game\Game\Facades\Game::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Game\\GameTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Game\Game\Providers\GameServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Game\Game\Providers\GameServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Game\Game\Providers\GameServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/game/{modulename}

**User**

    http://path-to-route-folder/user/game/{modulename}

**Public**

    http://path-to-route-folder/games


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/game/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/game/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/game/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/game/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/game/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/game/{modulename}/{slug}
    METHOD: GET