<?php

namespace Game\Game\Policies;

use Litepie\User\Contracts\UserPolicy;
use Game\Game\Models\Categories;

class CategoriesPolicy
{

    /**
     * Determine if the given user can view the categories.
     *
     * @param UserPolicy $user
     * @param Categories $categories
     *
     * @return bool
     */
    public function view(UserPolicy $user, Categories $categories)
    {
        if ($user->canDo('game.categories.view') && $user->isAdmin()) {
            return true;
        }

        return $categories->user_id == user_id() && $categories->user_type == user_type();
    }

    /**
     * Determine if the given user can create a categories.
     *
     * @param UserPolicy $user
     * @param Categories $categories
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('game.categories.create');
    }

    /**
     * Determine if the given user can update the given categories.
     *
     * @param UserPolicy $user
     * @param Categories $categories
     *
     * @return bool
     */
    public function update(UserPolicy $user, Categories $categories)
    {
        if ($user->canDo('game.categories.edit') && $user->isAdmin()) {
            return true;
        }

        return $categories->user_id == user_id() && $categories->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given categories.
     *
     * @param UserPolicy $user
     * @param Categories $categories
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Categories $categories)
    {
        return $categories->user_id == user_id() && $categories->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given categories.
     *
     * @param UserPolicy $user
     * @param Categories $categories
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Categories $categories)
    {
        if ($user->canDo('game.categories.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given categories.
     *
     * @param UserPolicy $user
     * @param Categories $categories
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Categories $categories)
    {
        if ($user->canDo('game.categories.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
