<?php

namespace Game\Game\Policies;

use Litepie\User\Contracts\UserPolicy;
use Game\Game\Models\Game;

class GamePolicy
{

    /**
     * Determine if the given user can view the game.
     *
     * @param UserPolicy $user
     * @param Game $game
     *
     * @return bool
     */
    public function view(UserPolicy $user, Game $game)
    {
        if ($user->canDo('game.game.view') && $user->isAdmin()) {
            return true;
        }

        return $game->user_id == user_id() && $game->user_type == user_type();
    }

    /**
     * Determine if the given user can create a game.
     *
     * @param UserPolicy $user
     * @param Game $game
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('game.game.create');
    }

    /**
     * Determine if the given user can update the given game.
     *
     * @param UserPolicy $user
     * @param Game $game
     *
     * @return bool
     */
    public function update(UserPolicy $user, Game $game)
    {
        if ($user->canDo('game.game.edit') && $user->isAdmin()) {
            return true;
        }

        return $game->user_id == user_id() && $game->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given game.
     *
     * @param UserPolicy $user
     * @param Game $game
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Game $game)
    {
        return $game->user_id == user_id() && $game->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given game.
     *
     * @param UserPolicy $user
     * @param Game $game
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Game $game)
    {
        if ($user->canDo('game.game.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given game.
     *
     * @param UserPolicy $user
     * @param Game $game
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Game $game)
    {
        if ($user->canDo('game.game.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
